@@ -7,8 +7,8 @@
  *
  *  The iODBC driver manager.
  *
- *  Copyright (C) 1995 by Ke Jin <kejin@empress.com>
- *  Copyright (C) 1996-2016 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1995 Ke Jin <kejin@empress.com>
+ *  Copyright (C) 1996-2023 OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -84,7 +84,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-#if defined(__WCHAR_TYPE__) && !defined(MACOSX102)
+#if defined(__WCHAR_TYPE__)
 #include <wchar.h>
 #endif
 
